@@ -1,6 +1,7 @@
-from logilab.common.testlib import unittest_main
+import unittest
 from cubicweb.devtools.testlib import AutomaticWebTest
 
+
 class AutomaticWebTest(AutomaticWebTest):
 
     def to_test_etypes(self):
@@ -9,5 +10,6 @@ class AutomaticWebTest(AutomaticWebTest):
     def list_startup_views(self):
         return ()
 
+
 if __name__ == '__main__':
-    unittest_main()
+    unittest.main()
