@@ -1,6 +1,7 @@
 import re
 from lxml import etree
 
+from cubicweb.devtools import BASE_URL
 from cubicweb.devtools.testlib import CubicWebTC
 
 from cubicweb_comment import views
@@ -125,7 +126,7 @@ Yeah !""", content_format=u"text/html", comments=c)
             # remove date
             content = re.sub('..../../.. ..:..', '', content)
             self.assertMultiLineEqual(content,
-                                      """\
+                                      f"""\
 > On  - admin wrote :
 > bouh!
 
@@ -134,7 +135,7 @@ some extra xxxxxxx. Yeah !
 
 
 i18n_by_author_field: admin
-url: http://testing.fr/cubicweb/blogentry/%s""" % self.b)
+url: {BASE_URL}blogentry/%s""" % self.b)
             # fullthreadtext_descending view
             self.assertMultiLineEqual('''On  - admin wrote :
 bouh!
@@ -195,8 +196,8 @@ bouh!
             doc = etree.fromstring(xmldata, etree.XMLParser(recover=True))
             self.assertEqual(
                 [node.text for node in doc.xpath('//guid')], [
-                    'http://testing.fr/cubicweb/comment/{}'.format(c1.eid),
-                    'http://testing.fr/cubicweb/comment/{}'.format(c2.eid),
+                    '{}comment/{}'.format(BASE_URL, c1.eid),
+                    '{}comment/{}'.format(BASE_URL, c2.eid),
                 ])
 
 
